==> moodle-2.0.tbz: www/moodle/blocks/rss_client/lang/en/block_rss_client.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_rss_client', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_rss_client
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['addfeed'] = 'Add a news feed URL:';
$string['addheadlineblock'] = 'Add RSS headline block';
$string['addnew'] = 'Add New';
$string['addnewfeed'] = 'Add a new feed';
$string['cannotmakemodification'] = 'You are not allowed to make modifications to this RSS feed at this time.';
$string['clientchannellink'] = 'Source site...';
$string['clientnumentries'] = 'The default number of entries to show per feed.';
$string['clientshowchannellinklabel'] = 'Should a link to the original site (channel link) be displayed? (Note that if no feed link is supplied in the news feed then no link will be shown) :';
$string['clientshowimagelabel'] = 'Show channel image if available :';
$string['configblock'] = 'Configure this block';
$string['couldnotfindfeed'] = 'Could not find feed with id';
$string['customtitlelabel'] = 'Custom title (leave blank to use title supplied by feed):';
$string['deletefeedconfirm'] = 'Are you sure you want to delete this feed?';
$string['disabledrssfeeds'] = 'RSS feeds are disabled';
$string['displaydescriptionlabel'] = 'Display each link\'s description?';
$string['editafeed'] = 'Edit a feed';
$string['editfeeds'] = 'Edit, subscribe or unsubscribe from RSS/Atom news feeds';
$string['editnewsfeeds'] = 'Edit news feeds';
$string['editrssblock'] = 'Edit RSS Headline Block';
$string['enableautodiscovery'] = 'Enable auto-discovery of feeds?';
$string['enableautodiscovery_help'] = 'If enabled, feeds on web pages are found automatically. For example, if http://docs.moodle.org is entered, then http://docs.moodle.org/en/index.php?title=Special:RecentChanges&feed=rss would be found.';
$string['errorloadingfeed'] = 'Error loading this RSS feed ({$a})';
$string['feed'] = 'Feed';
$string['feedadded'] = 'News feed added';
$string['feeddeleted'] = 'News feed deleted';
$string['feeds'] = 'News Feeds';
$string['feedsaddedit'] = 'Add/Edit Feeds';
$string['feedsconfigurenewinstance'] = 'Click here to configure this block to display RSS feeds.';
$string['feedsconfigurenewinstance2'] = 'Click the edit icon above to configure this block to display RSS feeds.';
$string['feedstitle'] = 'Remote RSS Feeds';
$string['feedupdated'] = 'News feed updated';
$string['feedurl'] = 'Feed URL';
$string['findmorefeeds'] = 'Find more RSS feeds';
$string['choosefeedlabel'] = 'Choose the feeds which you would like to make available in this block:';
$string['managefeeds'] = 'Manage all my feeds';
$string['nofeeds'] = 'There are no RSS feeds defined for this site.';
$string['numentries'] = 'Entries per feed';
$string['pickfeed'] = 'Pick a news feed';
$string['pluginname'] = 'RSS client';
$string['remotenewsfeed'] = 'Remote News Feed';
$string['rss_client:createprivatefeeds'] = 'Create private RSS feeds';
$string['rss_client:createsharedfeeds'] = 'Create shared RSS feeds';
$string['rss_client:manageanyfeeds'] = 'Manage any RSS feeds';
$string['rss_client:manageownfeeds'] = 'Manage own RSS feeds';
$string['seeallfeeds'] = 'See all feeds';
$string['sharedfeed'] = 'Shared feed';
$string['shownumentrieslabel'] = 'Max number entries to show per block.';
$string['submitters'] = 'Who will be allowed to define new RSS feeds? Defined feeds are available for any page on your site.';
$string['submitters2'] = 'Submitters';
$string['timeout'] = 'Time in minutes before an RSS feed expires in cache. Note that this time defines the minimum time before expiry; the feed will be refreshed in cache on the next cron execution after expiry. Recommended values are 30 mins or greater.';
$string['timeoutdesc'] = 'Time in minutes for an RSS feed to live in cache.';
$string['timeout2'] = 'Timeout';
$string['updatefeed'] = 'Update a news feed URL:';
$string['viewfeed'] = 'View feed';

==> moodle-2.2.4.tbz: www/moodle/blocks/rss_client/lang/en/block_rss_client.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_rss_client', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_rss_client
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['addfeed'] = 'Add a news feed URL:';
$string['addheadlineblock'] = 'Add RSS headline block';
$string['addnew'] = 'Add new';
$string['addnewfeed'] = 'Add a new feed';
$string['cannotmakemodification'] = 'You are not allowed to make modifications to this RSS feed at this time.';
$string['clientchannellink'] = 'Source site...';
$string['clientnumentries'] = 'The default number of entries to show per feed.';
$string['clientshowchannellinklabel'] = 'Should a link to the original site (channel link) be displayed? (Note that if no feed link is supplied in the news feed then no link will be shown) :';
$string['clientshowimagelabel'] = 'Show channel image if available :';
$string['configblock'] = 'Configure this block';
$string['couldnotfindfeed'] = 'Could not find feed with id';
$string['customtitlelabel'] = 'Custom title (leave blank to use title supplied by feed):';
$string['deletefeedconfirm'] = 'Are you sure you want to delete this feed?';
$string['disabledrssfeeds'] = 'RSS feeds are disabled';
$string['displaydescriptionlabel'] = 'Display each link\'s description?';
$string['editafeed'] = 'Edit a feed';
$string['editfeeds'] = 'Edit, subscribe or unsubscribe from RSS/Atom news feeds';
$string['editnewsfeeds'] = 'Edit news feeds';
$string['editrssblock'] = 'Edit RSS headline block';
$string['enableautodiscovery'] = 'Enable auto-discovery of feeds?';
$string['enableautodiscovery_help'] = 'If enabled, feeds on web pages are found automatically. For example, if http://docs.moodle.org is entered, then http://docs.moodle.org/en/index.php?title=Special:RecentChanges&feed=rss would be found.';
$string['errorloadingfeed'] = 'Error loading this RSS feed ({$a})';
$string['feed'] = 'Feed';
$string['feedadded'] = 'News feed added';
$string['feeddeleted'] = 'News feed deleted';
$string['feeds'] = 'News feeds';
$string['feedsaddedit'] = 'Add/edit feeds';
$string['feedsconfigurenewinstance'] = 'Click here to configure this block to display RSS feeds.';
$string['feedsconfigurenewinstance2'] = 'Click the edit icon above to configure this block to display RSS feeds.';
$string['feedstitle'] = 'Remote RSS Feeds';
$string['feedupdated'] = 'News feed updated';
$string['feedurl'] = 'Feed URL';
$string['findmorefeeds'] = 'Find more RSS feeds';
$string['choosefeedlabel'] = 'Choose the feeds which you would like to make available in this block:';
$string['managefeeds'] = 'Manage all my feeds';
$string['nofeeds'] = 'There are no RSS feeds defined for this site.';
$string['numentries'] = 'Entries per feed';
$string['pickfeed'] = 'Pick a news feed';
$string['pluginname'] = 'RSS client';
$string['remotenewsfeed'] = 'Remote news feed';
$string['rss_client:createprivatefeeds'] = 'Create private RSS feeds';
$string['rss_client:createsharedfeeds'] = 'Create shared RSS feeds';
$string['rss_client:manageanyfeeds'] = 'Manage any RSS feeds';
$string['rss_client:manageownfeeds'] = 'Manage own RSS feeds';
$string['seeallfeeds'] = 'See all feeds';
$string['sharedfeed'] = 'Shared feed';
$string['shownumentrieslabel'] = 'Max number entries to show per block.';
$string['submitters'] = 'Who will be allowed to define new RSS feeds? Defined feeds are available for any page on your site.';
$string['submitters2'] = 'Submitters';
$string['timeout'] = 'Time in minutes before an RSS feed expires in cache. Note that this time defines the minimum time before expiry; the feed will be refreshed in cache on the next cron execution after expiry. Recommended values are 30 mins or greater.';
$string['timeoutdesc'] = 'Time in minutes for an RSS feed to live in cache.';
$string['timeout2'] = 'Timeout';
$string['updatefeed'] = 'Update a news feed URL:';
$string['viewfeed'] = 'View feed';
